{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "bg",
  "clipboard.copy": "Копирай",
  "clipboard.copied": "Копирано",
  "edit.link.title": "Редактирай тази страница",
  "footer.previous": "Предишна",
  "footer.next": "Следваща",
  "footer.title": "Долен колонтитул",
  "header.title": "Горен колонтитул",
  "meta.comments": "Коментари",
  "meta.source": "Код",
  "nav.title": "Навигация",
  "search.config.lang": "ru",
  "search.placeholder": "Търси",
  "search.reset": "Изчисти",
  "search.result.placeholder": "Започнете да пишете, за да търсите",
  "search.result.none": "Няма резултати",
  "search.result.one": "1 резултат",
  "search.result.other": "# резултата",
  "search.result.more.one": "още 1 на тази страница",
  "search.result.more.other": "още # на тази страница",
  "skip.link.title": "Към съдържанието",
  "source.link.title": "Към хранилището",
  "source.revision.date": "Последна промяна",
  "source.file.date.updated": "Последна промяна",
  "source.file.date.created": "Създаден",
  "tabs.title": "Табове",
  "toc.title": "Съдържание"
}[key] }}{% endmacro %}
