{#-
  This file was automatically generated - do not edit
-#}
{% import "partials/language.html" as lang with context %}
<footer class="md-footer">
  {% if page.previous_page or page.next_page %}
    <nav class="md-footer__inner md-grid" aria-label="{{ lang.t('footer.title') }}">
      {% if page.previous_page %}
        {% set direction = lang.t("footer.previous") %}
        <a href="{{ page.previous_page.url | url }}" class="md-footer__link md-footer__link--prev" aria-label="{{ direction }}: {{ page.previous_page.title | e }}" rel="prev">
          <div class="md-footer__button md-icon">
            {% include ".icons/material/arrow-left.svg" %}
          </div>
          <div class="md-footer__title">
            <div class="md-ellipsis">
              <span class="md-footer__direction">
                {{ direction }}
              </span>
              {{ page.previous_page.title }}
            </div>
          </div>
        </a>
      {% endif %}
      {% if page.next_page %}
        {% set direction = lang.t("footer.next") %}
        <a href="{{ page.next_page.url | url }}" class="md-footer__link md-footer__link--next" aria-label="{{ direction }}: {{ page.next_page.title | e }}" rel="next">
          <div class="md-footer__title">
            <div class="md-ellipsis">
              <span class="md-footer__direction">
                {{ direction }}
              </span>
              {{ page.next_page.title }}
            </div>
          </div>
          <div class="md-footer__button md-icon">
            {% include ".icons/material/arrow-right.svg" %}
          </div>
        </a>
      {% endif %}
    </nav>
  {% endif %}
  <div class="md-footer-meta md-typeset">
    <div class="md-footer-meta__inner md-grid">
      <div class="md-footer-copyright">
        <div class="md-footer-copyright__highlight">
          <div class="ob_footer_bottomHalf">
            <span>ICP备案: 京ICP备20024574号-1</span>
            <div class="diver"></div>
            <span>
                    <a href="https://www.oceanbase.com/protocols/ob_trial">OceanBase 软件许可协议</a>
                </span>
            <div class="diver"></div>
            <span>
                    <a href="https://open.oceanbase.com/protocols/ob_law">法律声明</a>
                </span>
            <span>
                    OceanBase 版权所有 © 2021 基础资源和备案服务由阿里云提供
                </span>
          </div>
        </div>
      </div>
      {% include "partials/social.html" %}
    </div>
  </div>
</footer>
