{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "kr",
  "clipboard.copy": "클립보드로 복사",
  "clipboard.copied": "클립보드에 복사됨",
  "edit.link.title": "이 페이지를 편집",
  "footer.previous": "이전",
  "footer.next": "다음",
  "meta.comments": "댓글",
  "meta.source": "출처",
  "search.config.pipeline": " ",
  "search.placeholder": "검색",
  "search.share": "공유",
  "search.reset": "지우기",
  "search.result.initializer": "검색 초기화",
  "search.result.placeholder": "검색어를 입력하세요",
  "search.result.none": "검색어와 일치하는 문서가 없습니다",
  "search.result.one": "1개의 일치하는 문서",
  "search.result.other": "#개의 일치하는 문서",
  "search.result.more.one": "이 문서에서 1개의 검색 결과 더 보기",
  "search.result.more.other": "이 문서에서 #개의 검색 결과 더 보기",
  "search.result.term.missing": "포함되지 않은 검색어",
  "search.title": "검색",
  "select.language.title": "언어설정",
  "select.version.title": "버전 선택",
  "skip.link.title": "콘텐츠로 이동",
  "source.link.title": "저장소로 이동",
  "source.revision.date": "마지막 업데이트",
  "source.file.date.updated": "마지막 업데이트",
  "source.file.date.created": "작성일",
  "toc.title": "목차",
  "top.title": "맨위로"
}[key] }}{% endmacro %}
